
.. blogpost::
    :title: Build wendelin.core on Windows
    :keywords: wendelin.core
    :date: 2016-08-31
    :categories: module, build

    Not easy !
    Unresolved.

    `wendelin.core <https://lab.nexedi.com/nexedi/wendelin.core>`_
